@@ -46,16 +46,13 @@
 
 #include "lateq.hh"
 #include "Text.hh"
-
-
-map<string, string>		gDocMathStringMap;
-set<string>				gDocMathKeySet;
+#include "exception.hh"
+#include "global.hh"
 
 static int	getLateqIndex(const string& s);
 static bool compLateqIndexes(const string& s1, const string& s2);
 static void initDocMathKeySet();
 
-
 template <class T>
 inline std::string to_string (const T& t)
 {
@@ -64,12 +61,9 @@ inline std::string to_string (const T& t)
 	return ss.str();
 }
 
-
 /****************************************************************
 				Top-level "println" method (public).
  *****************************************************************/
-
-
 /**
  * @brief 
  * Top-level method to print a whole set of compiled LaTeX formulas,
@@ -83,16 +77,16 @@ inline std::string to_string (const T& t)
 void Lateq::println(ostream& docout)
 {	
 	/* 1. Make titles of sub-sets of formulas. */
-	string suchthat		= gDocMathStringMap["suchthat"];
+	string suchthat		= gGlobal->gDocMathStringMap["suchthat"];
 	
-	string sInputs		= makeItemTitle(fInputSigsFormulas.size(), "inputsigtitle") + makeSignamesList(fInputSigsFormulas, "");
-	string sOutputs		= makeItemTitle(fOutputSigsFormulas.size(), "outputsigtitle") + makeSignamesList(fOutputSigsFormulas, suchthat);
-	string sConstants	= makeItemTitle(fConstSigsFormulas.size(), "constsigtitle") + makeSignamesList(fConstSigsFormulas, suchthat);
+	string sInputs		= makeItemTitle((const unsigned int)fInputSigsFormulas.size(), "inputsigtitle") + makeSignamesList(fInputSigsFormulas, "");
+	string sOutputs		= makeItemTitle((const unsigned int)fOutputSigsFormulas.size(), "outputsigtitle") + makeSignamesList(fOutputSigsFormulas, suchthat);
+	string sConstants	= makeItemTitle((const unsigned int)fConstSigsFormulas.size(), "constsigtitle") + makeSignamesList(fConstSigsFormulas, suchthat);
 	
 	vector<list<string> > UISignamesVector = makeUISignamesVector(fUISigsFormulas);
-	string sUIElements	= makeItemTitle(fUISigsFormulas.size(), "uisigtitle") + makeSignamesList(UISignamesVector, suchthat);
+	string sUIElements	= makeItemTitle((const unsigned int)fUISigsFormulas.size(), "uisigtitle") + makeSignamesList(UISignamesVector, suchthat);
 
-	unsigned int internalSigsCount = fParamSigsFormulas.size() + fStoreSigsFormulas.size() + fRecurSigsFormulas.size() + fRDTblSigsFormulas.size() + fRWTblSigsFormulas.size() + fSelectSigsFormulas.size() + fPrefixSigsFormulas.size();
+	unsigned int internalSigsCount = (unsigned int)(fParamSigsFormulas.size() + fStoreSigsFormulas.size() + fRecurSigsFormulas.size() + fRDTblSigsFormulas.size() + fRWTblSigsFormulas.size() + fSelectSigsFormulas.size() + fPrefixSigsFormulas.size());
 	
 	vector<list<string> > internalSigsFormulasList;
 	if( ! fParamSigsFormulas.empty() )	internalSigsFormulasList.push_back(fParamSigsFormulas);
@@ -107,12 +101,12 @@ void Lateq::println(ostream& docout)
 	
 	/* 2. Successively print each Lateq field containing LaTeX formulas, with a title. */
 	
-	docout << endl << gDocMathStringMap["lateqcomment"] << endl;
+	docout << endl << gGlobal->gDocMathStringMap["lateqcomment"] << endl;
 	docout << "\\begin{enumerate}" << endl << endl;
 	
 	printDGroup		(sOutputs, fOutputSigsFormulas, docout);
 	printOneLine	(sInputs, docout);
-	const string outputsTitle = "\\item " + sOutputs + "\\ $y_i$\\ " + gDocMathStringMap["for"] + " $i \\in [1," + to_string(fOutputSigsFormulas.size()) + "]$: ";
+	const string outputsTitle = "\\item " + sOutputs + "\\ $y_i$\\ " + gGlobal->gDocMathStringMap["for"] + " $i \\in [1," + to_string(fOutputSigsFormulas.size()) + "]$: ";
 	printHierarchy	(sUIElements, fUISigsFormulas, docout);
 	
 	/* The "Internal signals" item gather several fields, like a "super-item"... */
@@ -133,24 +127,20 @@ void Lateq::println(ostream& docout)
 	docout << "\\end{enumerate}" << endl << endl;
 }
 
-
-
 /****************************************************************
 				Item title making functions (public).
  *****************************************************************/
 
-
 string Lateq::makeItemTitle(const unsigned int formulasListSize, const string& titleName)
 {
 	string item		= "\\item ";
 	
 	/* Plural handling for titles of sub-sets of formulas. */
-	string title	= formulasListSize > 1 ? gDocMathStringMap[titleName + "2"] : gDocMathStringMap[titleName + "1"];
+	string title	= formulasListSize > 1 ? gGlobal->gDocMathStringMap[titleName + "2"] : gGlobal->gDocMathStringMap[titleName + "1"];
 	
 	return item + title;
 }
 
-
 string Lateq::makeSigDomain(const list<string>& formulasList)
 {
 	string signame = "";
@@ -161,7 +151,7 @@ string Lateq::makeSigDomain(const list<string>& formulasList)
 		signame = getSigName(firstEq);
 		
 		if(formulasList.size() > 1) {
-			sigDomain = " $" + signame + "_i$ " + gDocMathStringMap["for"] + " $i \\in [1," + to_string(formulasList.size()) + "]$";
+			sigDomain = " $" + signame + "_i$ " + gGlobal->gDocMathStringMap["for"] + " $i \\in [1," + to_string(formulasList.size()) + "]$";
 		} else {
 			if(signame == "x" || signame == "y") {
 				sigDomain = " $" + signame + "$"; ///< No indices for single input neither single output.
@@ -170,22 +160,20 @@ string Lateq::makeSigDomain(const list<string>& formulasList)
 			}
 		}
 	} else {
-		sigDomain = gDocMathStringMap["emptyformulafield"];
+		sigDomain = gGlobal->gDocMathStringMap["emptyformulafield"];
 	}
 	return sigDomain;
 }
 
-
 string Lateq::makeSignamesList(const list<string>& formulasList, const string& ending)
 {
 	if (formulasList.size() > 0) {
 		return makeSigDomain(formulasList) + " " + ending;
 	} else {
-		return " (" + gDocMathStringMap["emptyformulafield"] + ")";
+		return " (" + gGlobal->gDocMathStringMap["emptyformulafield"] + ")";
 	}
 }
 
-
 string Lateq::makeSignamesList(const vector<list<string> >& formulasListsVector, const string& ending)
 {
 	if (formulasListsVector.size() > 0) {
@@ -194,15 +182,14 @@ string Lateq::makeSignamesList(const vector<list<string> >& formulasListsVector,
 		string sep = " ";
 		for (it = formulasListsVector.begin(); it != formulasListsVector.end(); ++it) {
 			signames += sep + makeSigDomain(*it);
-			(it != (formulasListsVector.end() - 2)) ? sep = ", " : sep = " " + gDocMathStringMap["and"] + " ";
+			(it != (formulasListsVector.end() - 2)) ? sep = ", " : sep = " " + gGlobal->gDocMathStringMap["and"] + " ";
 		}
 		return signames + " " + ending;
 	} else {
-		return " (" + gDocMathStringMap["emptyformulafield"] + ")";
+		return " (" + gGlobal->gDocMathStringMap["emptyformulafield"] + ")";
 	}
 }
 
-
 string Lateq::getSigName(const string& s)
 {
 	size_t found;
@@ -228,7 +215,6 @@ string Lateq::getSigName(const string& s)
 	return signame;
 }
 
-
 vector<list<string> > Lateq::makeUISignamesVector(const multimap<string,string>& field)
 {
 	map<char,unsigned int> uiTypesMap;
@@ -248,16 +234,15 @@ vector<list<string> > Lateq::makeUISignamesVector(const multimap<string,string>&
 		} else {
 			++vIndex;
 			uiTypesMap.insert(pair<char,unsigned int>(type, vIndex));
-			list<string>* tmpList = new(list<string>);
-			tmpList->push_back(signame);
-			uiSignamesVector.push_back(*tmpList);
+            list<string> tmpList;
+			tmpList.push_back(signame);
+			uiSignamesVector.push_back(tmpList);
 		}
 	}
 	
 	return uiSignamesVector;
 }
 
-
 string Lateq::getUISigName(const string& s)
 {
 	size_t found;
@@ -271,7 +256,6 @@ string Lateq::getUISigName(const string& s)
 	return signame;
 }
 
-
 char Lateq::getUISigType(const string& s)
 {
 	size_t found;
@@ -285,13 +269,9 @@ char Lateq::getUISigType(const string& s)
 	return sigtype;
 }
 
-
-
 /****************************************************************
 				Secondary printing methods (private).
  *****************************************************************/
-
-
 /**
  * Print a sorted list of input signals names ("x_i"),
  * on a single line, separated by commas.
@@ -304,7 +284,6 @@ void Lateq::printOneLine(const string& section, ostream& docout)
 	docout << section << endl << endl;
 }
 
-
 /**
  * @brief Print a dgroup environment to auto-break long formulas.
  *
@@ -332,7 +311,6 @@ void Lateq::printDGroup(const string& section, list<string>& field, ostream& doc
 	}
 }
 
-
 /**
  * @brief Print formulas for user interface signals.
  *
@@ -389,7 +367,7 @@ void Lateq::printHierarchy(const string& section, multimap<string,string>& field
 					if (it->first != "") {
 						tab(n+0,docout); docout << "\\item \\textsf{" << it->first << "}" << endl;
 					} else { 
-						tab(n+0,docout); docout << "\\item \\emph{" << gDocMathStringMap["rootlevel"] << "}" << endl;
+						tab(n+0,docout); docout << "\\item \\emph{" << gGlobal->gDocMathStringMap["rootlevel"] << "}" << endl;
 					}
 				}
 				tab(n+1,docout); docout << "\\begin{center}" << endl;
@@ -408,7 +386,6 @@ void Lateq::printHierarchy(const string& section, multimap<string,string>& field
 	}
 }
 
-
 /**
  * @brief Print formulas for select2, select3 and prefix signals.
  *
@@ -434,14 +411,12 @@ void Lateq::printMath(const string& section, list<string>& field, ostream& docou
 	}
 }
 
-
 /** Simple handling of indentation. */
 void Lateq::tab (int n, ostream& docout) const
 { 
 	while (n--) docout << '\t'; 
 }
 
-
 /**
  * @brief Find out whether all keys of the multimap are empty or not.
  * 
@@ -460,8 +435,6 @@ bool Lateq::hasNotOnlyEmptyKeys(multimap<string,string>& mm)
 	return !hasOnlyEmptyPaths;
 }
 
-
-
 /** 
  * Dispatch initialization of autodoc container.
  */
@@ -470,12 +443,9 @@ void initDocMath()
 	initDocMathKeySet();
 }
 
-
 /****************************************************************
 				Internal static functions.
  *****************************************************************/
-
-
 /**
  * Compare indexes of two LaTeX strings, 
  * for the sort() method applied on list<string> fields.
@@ -485,7 +455,6 @@ static bool compLateqIndexes(const string& s1, const string& s2)
 	return getLateqIndex(s1) < getLateqIndex(s2);
 }
 
-
 /**
  * Find out the index of signals in LaTeX signal definition strings,
  * between the first "_{" and "}" patterns.
@@ -500,15 +469,15 @@ static int getLateqIndex(const string& s)
 	string sIndex;
 		
 	p1 = s.find("_{"); 
-	if (p1==string::npos) {
-		cerr << "Error : getLateqIndex found no \"{_\" substring.\n";
-		exit(1); }
+	if (p1 == string::npos) {
+        throw faustexception("ERROR : getLateqIndex found no \"{_\" substring.\n");
+    }
 	p1 += 2;
 	
 	p2 = s.find("}", p1); 
-	if (p2==string::npos) {
-		cerr << "Error : getLateqIndex found no \"}\" substring\n.";
-		exit(1); }
+	if (p2 == string::npos) {
+		throw faustexception("ERROR : getLateqIndex found no \"{_\" substring.\n");
+    }
 	p2 -= 3;
 	
 	sIndex = s.substr (p1, p2);
@@ -516,31 +485,30 @@ static int getLateqIndex(const string& s)
 	return atoi(sIndex.c_str());
 }
 
-
 /** 
- * Initialize gDocMathKeySet, a set containing all the keywords.
+ * Initialize gGlobal->gDocMathKeySet, a set containing all the keywords.
  */
 static void initDocMathKeySet()
 {
-	gDocMathKeySet.insert("inputsigtitle1");
-	gDocMathKeySet.insert("inputsigtitle2");
-	gDocMathKeySet.insert("outputsigtitle1");
-	gDocMathKeySet.insert("outputsigtitle2");
-	gDocMathKeySet.insert("constsigtitle1");
-	gDocMathKeySet.insert("constsigtitle2");
-	gDocMathKeySet.insert("uisigtitle1");
-	gDocMathKeySet.insert("uisigtitle2");
-	gDocMathKeySet.insert("intermedsigtitle1");
-	gDocMathKeySet.insert("intermedsigtitle2");
-	gDocMathKeySet.insert("lateqcomment");
-	gDocMathKeySet.insert("emptyformulafield");
-	gDocMathKeySet.insert("defaultvalue");
-	gDocMathKeySet.insert("suchthat");
-	gDocMathKeySet.insert("and");
-	gDocMathKeySet.insert("for");
-	gDocMathKeySet.insert("rootlevel");
+	gGlobal->gDocMathKeySet.insert("inputsigtitle1");
+	gGlobal->gDocMathKeySet.insert("inputsigtitle2");
+	gGlobal->gDocMathKeySet.insert("outputsigtitle1");
+	gGlobal->gDocMathKeySet.insert("outputsigtitle2");
+	gGlobal->gDocMathKeySet.insert("constsigtitle1");
+	gGlobal->gDocMathKeySet.insert("constsigtitle2");
+	gGlobal->gDocMathKeySet.insert("uisigtitle1");
+	gGlobal->gDocMathKeySet.insert("uisigtitle2");
+	gGlobal->gDocMathKeySet.insert("intermedsigtitle1");
+	gGlobal->gDocMathKeySet.insert("intermedsigtitle2");
+	gGlobal->gDocMathKeySet.insert("lateqcomment");
+	gGlobal->gDocMathKeySet.insert("emptyformulafield");
+	gGlobal->gDocMathKeySet.insert("defaultvalue");
+	gGlobal->gDocMathKeySet.insert("suchthat");
+	gGlobal->gDocMathKeySet.insert("and");
+	gGlobal->gDocMathKeySet.insert("for");
+	gGlobal->gDocMathKeySet.insert("rootlevel");
 
-	gDocMathKeySet.insert("dgmcaption");
+	gGlobal->gDocMathKeySet.insert("dgmcaption");
 }
 
 
