@@ -18,31 +18,28 @@
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  ************************************************************************
  ************************************************************************/
- 
- 
- 
-// device.h
-
 
 #if !defined DEVICE_H
 #define DEVICE_H
 
-#include "stdio.h"
+#include "garbageable.hh"
+#include <stdio.h>
 
-class device  
+class device : public virtual Garbageable
 {
 	public:
         virtual ~device() {}
-        virtual void rect(double,double,double,double, const char*, const char*)=0;
-		virtual void rond(double,double,double)=0;
-		virtual void carre(double,double,double)=0;
-		virtual void fleche(double,double,double,int)=0;
-		virtual void trait(double,double,double,double)=0;
-		virtual void dasharray(double,double,double,double)=0;
-		virtual void text(double,double,const char*)=0;
-		virtual void label(double,double,const char*)=0;
-		virtual void markSens(double,double,int)=0;
-		virtual void Error(const char*,const char*,int,double,double,double)=0;
+        virtual void rect(double x,double y,double l,double h, const char* color, const char* link)=0;
+        virtual void triangle(double x,double y,double l,double h, const char* color, const char* link, bool leftright)=0;
+        virtual void rond(double x,double y,double rayon)=0;
+        virtual void carre(double x,double y,double cote)=0;
+        virtual void fleche(double x,double y,double rotation,int sens)=0;
+        virtual void trait(double x1,double y1,double x2,double y2)=0;
+        virtual void dasharray(double x1,double y1,double x2,double y2)=0;
+        virtual void text(double x,double y,const char* name, const char* link)=0;
+        virtual void label(double x,double y,const char* name)=0;
+        virtual void markSens(double x,double y,int sens)=0;
+        virtual void Error(const char* message, const char* reason,int nb_error,double x,double y,double largeur)=0;
 	
 	protected:
 		FILE* fic_repr;
