@@ -323,12 +323,12 @@ global::global():TABBER(1), gLoopDetector(1024, 400), gNextFreeColor(1)
     PATHCURRENT = symbol(".");
     FFUN = symbol("ForeignFunction");
 
-    SIGINPUT = symbol("sigInput");
-    SIGOUTPUT = symbol("sigOutput");
-    SIGDELAY1 = symbol("sigDelay1");
-    SIGFIXDELAY = symbol("sigFixDelay");
-    SIGPREFIX = symbol("sigPrefix");
-    SIGIOTA = symbol("sigIota");
+    SIGINPUT = symbol("SigInput");
+    SIGOUTPUT = symbol("SigOutput");
+    SIGDELAY1 = symbol("SigDelay1");
+    SIGFIXDELAY = symbol("SigFixDelay");
+    SIGPREFIX = symbol("SigPrefix");
+    SIGIOTA = symbol("SigIota");
     SIGRDTBL = symbol("SigRDTbl");
     SIGWRTBL = symbol("SigWRTbl");
     SIGTABLE = symbol("SigTable");
@@ -343,8 +343,8 @@ global::global():TABBER(1), gLoopDetector(1024, 400), gNextFreeColor(1)
     SIGFCONST = symbol("SigFConst");
     SIGFVAR = symbol("SigFVar");
     SIGPROJ = symbol("SigProj");
-    SIGINTCAST = symbol("sigIntCast");
-    SIGFLOATCAST = symbol("sigFloatCast");
+    SIGINTCAST = symbol("SigIntCast");
+    SIGFLOATCAST = symbol("SigFloatCast");
     SIGBUTTON = symbol("SigButton");
     SIGCHECKBOX = symbol("SigCheckbox");
     SIGWAVEFORM = symbol("SigWaveform");
@@ -353,13 +353,14 @@ global::global():TABBER(1), gLoopDetector(1024, 400), gNextFreeColor(1)
     SIGNUMENTRY = symbol("SigNumEntry");
     SIGHBARGRAPH = symbol("SigHBargraph");
     SIGVBARGRAPH = symbol("SigVBargraph");
-    SIGATTACH = symbol("sigAttach");
-    SIGENABLE = symbol("sigEnable");
-    SIGCONTROL = symbol("sigControl");
-    SIGSOUNDFILE = symbol("sigSoundfile");
-    SIGSOUNDFILELENGTH = symbol("sigSoundfileLength");
-    SIGSOUNDFILERATE = symbol("sigSoundfileRate");
-    SIGSOUNDFILECHANNEL = symbol("sigSoundfileChannel");
+    SIGATTACH = symbol("SigAttach");
+    SIGENABLE = symbol("SigEnable");
+    SIGCONTROL = symbol("SigControl");
+    SIGSOUNDFILE = symbol("SigSoundfile");
+    SIGSOUNDFILELENGTH = symbol("SigSoundfileLength");
+    SIGSOUNDFILERATE = symbol("SigSoundfileRate");
+    SIGSOUNDFILECHANNELS = symbol("SigSoundfileChannels");
+    SIGSOUNDFILEBUFFER = symbol("SigSoundfileBuffer");
     SIGTUPLE = symbol("SigTuple");
     SIGTUPLEACCESS = symbol("SigTupleAccess");
     SIMPLETYPE = symbol("SimpleType");
