@@ -1,5 +1,28 @@
+/************************************************************************
+ ************************************************************************
+    FAUST compiler
+	Copyright (C) 2003-2004 GRAME, Centre National de Creation Musicale
+    ---------------------------------------------------------------------
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ ************************************************************************
+ ************************************************************************/
+ 
 #include <stdio.h>
-#include <assert.h>
+#include <map>
+#include <list>
+
 #include "tlib.hh"
 #include "signals.hh"
 #include "sigprint.hh"
@@ -7,11 +30,9 @@
 #include "simplify.hh"
 #include "normalize.hh"
 #include "sigorderrules.hh"
-#include <map>
-#include <list>
-
 #include "mterm.hh"
 #include "aterm.hh"
+#include "exception.hh"
 
 #if 0
 static void countAddTerm (map<Tree,Tree>& M, Tree t, bool invflag);
@@ -36,14 +57,22 @@ Tree normalizeAddTerm(Tree t)
 #endif
 	
 	aterm A(t);
-	//cerr << "ATERM IS : " << A << endl;
+#ifdef TRACE
+	cerr << "ATERM of " << A << endl;
+#endif
 	mterm D = A.greatestDivisor();
 	while (D.isNotZero() && D.complexity() > 0) {
-		//cerr << "GREAT DIV : " << D << endl;
+#ifdef TRACE
+		cerr << "*** GREAT DIV : " << D << endl;
+#endif
 		A = A.factorize(D);
 		D = A.greatestDivisor();
 	}
-	return A.normalizedTree();
+	Tree r = A.normalizedTree();
+#ifdef TRACE
+    cerr << "ATERM of " << A << " --> " << ppsig(r) << endl;
+#endif
+    return r;
 }
 
 
