@@ -342,21 +342,24 @@ bool isSigDiv(Tree a, Tree& x, Tree& y)
 							 Sounfiles
 *****************************************************************************/
 /*
-A boxSounfile(label,c) has 1 input channel and c+2 output channels:
-    0   sigSoundfileLength(sigSoundfile(label)):  the number of frames of the soundfile (NK)
-    1   sigSoundfileSamplingRate(sigSoundfile(label)): the sampling rate encoded in the file (NK)
-    2.. sigSoundfileChannel(sigSoundfile(label), c, ridx): the cth channel content (RK ou RS)
+ A boxSounfile(label,c) has 1 input channel and c+3 output channels:
+ 0   sigSoundfileLength(label):  the number of frames of the soundfile (NK)
+ 1   sigSoundfileRate(label): the sampling rate encoded in the file (NK)
+ 2   sigSoundfileChannels(label): the number of channels of the file (NK)
+ 3.. sigSoundfileBuffer(label, c, ridx): the cth channel content (RK ou RS)
 */
 Tree sigSoundfile(Tree label)							{ return tree(gGlobal->SIGSOUNDFILE, label); }
 Tree sigSoundfileLength(Tree sf)						{ return tree(gGlobal->SIGSOUNDFILELENGTH, sf); }
 Tree sigSoundfileRate(Tree sf)							{ return tree(gGlobal->SIGSOUNDFILERATE, sf); }
-Tree sigSoundfileChannel(Tree sf, Tree chan, Tree ridx)	{ return tree(gGlobal->SIGSOUNDFILECHANNEL, sf, chan, ridx); }
+Tree sigSoundfileChannels(Tree sf)						{ return tree(gGlobal->SIGSOUNDFILECHANNELS, sf); }
+Tree sigSoundfileBuffer(Tree sf, Tree chan, Tree ridx)	{ return tree(gGlobal->SIGSOUNDFILEBUFFER, sf, chan, ridx); }
 
 bool isSigSoundfile(Tree s, Tree& label)				{ return isTree(s, gGlobal->SIGSOUNDFILE, label); }
 bool isSigSoundfileLength(Tree s, Tree& sf)				{ return isTree(s, gGlobal->SIGSOUNDFILELENGTH, sf); }
 bool isSigSoundfileRate(Tree s, Tree& sf)				{ return isTree(s, gGlobal->SIGSOUNDFILERATE, sf); }
-bool isSigSoundfileChannel(Tree s, Tree& sf, Tree& chan, Tree& ridx)
-															{ return isTree(s, gGlobal->SIGSOUNDFILECHANNEL, sf, chan, ridx); }
+bool isSigSoundfileChannels(Tree s, Tree& sf)			{ return isTree(s, gGlobal->SIGSOUNDFILECHANNELS, sf); }
+bool isSigSoundfileBuffer(Tree s, Tree& sf, Tree& chan, Tree& ridx)
+															{ return isTree(s, gGlobal->SIGSOUNDFILEBUFFER, sf, chan, ridx); }
 /*****************************************************************************
 							 matrix extension
 *****************************************************************************/
