@@ -31,7 +31,7 @@
 #include "faust/dsp/poly-dsp.h"
 
 #ifndef WIN32
-#include "faust/sound-file.h"
+//#include "faust/sound-file.h"
 #endif
 
 int faustgen_factory::gFaustCounter = 0;
@@ -310,7 +310,7 @@ llvm_dsp_factory* faustgen_factory::create_factory_from_sourcecode()
     }
 
 #ifdef WIN32
-    argv[fCompileOptions.size()] = "-l";
+    argv[fCompileOptions.size()] = "-L";
     argv[fCompileOptions.size() + 1] = "llvm_math.ll";
     argv[fCompileOptions.size() + 2] = 0;  // NULL terminated argv
     llvm_dsp_factory* factory = createDSPFactoryFromString(name_app, *fSourceCode, fCompileOptions.size() + 2, argv, getTarget(), error, fOptLevel);
@@ -1061,7 +1061,6 @@ faustgen::faustgen(t_symbol* sym, long ac, t_atom* argv)
      
     // Fetch the data inside the max patcher using the dictionary
     t_dictionary* d = 0;
-    
     if ((d = (t_dictionary*)gensym("#D")->s_thing) && res) {
         fDSPfactory->getfromdictionary(d);
     }
@@ -1573,9 +1572,17 @@ void faustgen::create_jsui()
         obj = jbox_get_object(box);
         // Notify JSON
         if (obj && strcmp(object_classname(obj)->s_name, "js") == 0) {
-            t_atom json;
-            atom_setsym(&json, gensym(fDSPfactory->get_json()));
-            object_method_typed(obj, gensym("anything"), 1, &json, 0);
+            t_atom argv[2];
+            // Add JSON parameter
+            atom_setsym(&argv[0], gensym(fDSPfactory->get_json()));
+            // Add scripting name parameter
+            t_object* fg_box;
+            object_obex_lookup((t_object*)&m_ob, gensym("#B"), &fg_box);
+            t_symbol* scripting = jbox_get_varname(fg_box); // scripting name
+            if (scripting) {
+                atom_setsym(&argv[1], gensym(scripting->s_name));
+            }
+            object_method_typed(obj, gensym("anything"), 2, argv, 0);
         }
     }
         
